@@ -5,7 +5,7 @@
 # Joan Ntzougani, ✞
 
 package Dancer2::Plugin::WebService;
-our	$VERSION = '4.3.8';
+our	$VERSION = '4.3.9';
 use	strict;
 use	warnings;
 use Encode;
@@ -247,6 +247,12 @@ closedir DIR;
 			$app->halt($plg->reply('error'=>'Data parsing as '.$plg->Format->{from}." failed because $@"))
 			}
 		}
+
+	# Delete not needed url parameters
+	delete $app->request->query_parameters->{$_} foreach qw/from to sort pretty message/;
+
+	# We add to the data also any url parameter the user pass
+	foreach (keys %{$app->request->query_parameters}) { $plg->data->{$_} = $app->request->query_parameters->{$_} }
 	}));
 
 
@@ -745,7 +751,7 @@ Dancer2::Plugin::WebService - RESTful Web Services with login, persistent data,
 
 =head1 VERSION
 
-version 4.3.8
+version 4.3.9
 
 =head2 SYNOPSIS
 
